class OverlayAnimation {
  constructor(elm) {
    /*settings you can change*/
    this.numPoints = 50;
    this.duration = 1800;
    this.delayPointsMax = 600;
    this.delayPerPath = 200;
    /*end*/

    this.delayPointsArray = [];
    this.path = elm.querySelectorAll('path');
    this.timeStart = Date.now();
    this.isAnimating = false;
  }
  animate() {
    this.isAnimating = true;
    const range = 4 * Math.random() + 6;
    for (var i = 0; i < this.numPoints; i++) {
      const radian = i / (Math.floor((Math.random() * 25) + 10) - 1) * Math.PI;
      this.delayPointsArray[i] = (Math.sin(-radian) + Math.sin(-radian * range) + 2) / 4 * this.delayPointsMax;
    }
    this.renderLoop();
  }
  updatePath(time) {
    const points = [];
    for (var i = 0; i < this.numPoints + 1; i++) {
      points[i] = ease.cubicInOut(Math.min(Math.max(time - this.delayPointsArray[i], 0) / this.duration, 1)) * 100
    }

    let str = '';
    str += `M 0 ${points[0]} `;
    for (var i = 0; i < this.numPoints - 1; i++) {
      const p = (i + 1) / (this.numPoints - 1) * 100;
      const cp = p - (1 / (this.numPoints - 1) * 100) / 2;
      str += `C ${cp} ${points[i]} ${cp} ${points[i + 1]} ${p} ${points[i + 1]} `;
    }
    str += `V 100 H 0`;
    return str;
  }
  renderLoop() {
    for (var i = 0; i < this.path.length; i++) {
      this.path[i].setAttribute('d', this.updatePath(Date.now() - (this.timeStart + this.delayPerPath * (this.path.length - i - 1))));
    }
    if (Date.now() - this.timeStart < this.duration + this.delayPerPath * (this.path.length - 1) + this.delayPointsMax) {
      requestAnimationFrame(() => {
        this.renderLoop();
      });
    } else {
      // End of animation. Add something here if you want to.
      this.isAnimating = false;
    }
  }
}

(function() {
  const elmOverlay = document.querySelector('.group-overlays');
  const overlay = new OverlayAnimation(elmOverlay);
  overlay.animate();
}());
